==> ms-users-12.1.1.tgz: package/lib/actions/organization/list.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  ActionTransport
} = require('@microfleet/core');

const Promise = require('bluebird');

const fsort = require('redis-filtered-sort');

const redisKey = require('../../utils/key');

const {
  getOrganizationMetadata,
  getInternalData
} = require('../../utils/organization');

const {
  ORGANIZATIONS_INDEX,
  ORGANIZATIONS_DATA
} = require('../../constants');
/**
 * @api {amqp} <prefix>.list Retrieve Organizations list
 * @apiVersion 1.0.0
 * @apiName ListOrganizations
 * @apiGroup Organizations
 *
 * @apiDescription This method allows to list organizations. They can be sorted & filtered by
 * any metadata field.
 *
 * @apiParam (Payload) {Number} [offset=0] - cursor for pagination
 * @apiParam (Payload) {Number} [limit=10] - profiles per page
 * @apiParam (Payload) {String="ASC","DESC"} [order=ASC] - sort order
 * @apiParam (Payload) {String} [criteria] - if supplied, sort will be performed based on this field
 * @apiParam (Payload) {Object} [filter] to use, consult https://github.com/makeomatic/redis-filtered-sort, can already be stringified

 * @apiSuccess (Response) {Object[]} data - response data.
 * @apiSuccess (Response) {String} data.id - organization id.
 * @apiSuccess (Response) {String} data.type - response type.
 * @apiSuccess (Response) {String} data.attributes.id - organization id.
 * @apiSuccess (Response) {String} data.attributes.name - organization name.
 * @apiSuccess (Response) {Boolean} data.attributes.active - organization state.
 * @apiSuccess (Response) {Object} data.attributes.metadata - organization metadata
 * @apiSuccess (Response) {Object} meta - response meta.
 * @apiSuccess (Response) {Number} meta.cursor - cursor.
 * @apiSuccess (Response) {Number} meta.page - page.
 * @apiSuccess (Response) {Number} meta.pages - pages.
 * @apiSuccess (Response) {Number} meta.total - total.
 */


async function getOrganizationsList({
  params
}) {
  const {
    redis
  } = this;
  const {
    criteria,
    limit = 10,
    offset = 0,
    order = 'ASC',
    expiration = 30000,
    filter
  } = params;
  const strFilter = typeof filter === 'string' ? filter : fsort.filter(filter || {});
  const currentTime = Date.now();
  const organizationsIds = await redis.fsort(ORGANIZATIONS_INDEX, redisKey('*', ORGANIZATIONS_DATA), criteria, order, strFilter, currentTime, offset, limit, expiration);
  const length = +organizationsIds.pop();
  const organizations = await Promise.map(organizationsIds, async organizationId => {
    const [organization, metadata] = await Promise.all([getInternalData.call(this, organizationId, true), getOrganizationMetadata.call(this, organizationId)]);
    return _objectSpread({}, organization, {
      metadata
    });
  });
  return {
    data: organizations.map(organization => ({
      id: organization.id,
      type: 'organization',
      attributes: organization
    })),
    meta: {
      cursor: offset + limit,
      page: Math.floor(offset / limit) + 1,
      pages: Math.ceil(length / limit),
      total: length
    }
  };
}

getOrganizationsList.transports = [ActionTransport.amqp, ActionTransport.internal];
module.exports = getOrganizationsList;

==> ms-users-14.1.1.tgz: package/lib/actions/organization/list.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  ActionTransport
} = require('@microfleet/core');

const Promise = require('bluebird');

const fsort = require('redis-filtered-sort');

const redisKey = require('../../utils/key');

const {
  getOrganizationMetadata,
  getInternalData
} = require('../../utils/organization');

const {
  ORGANIZATIONS_INDEX,
  ORGANIZATIONS_DATA
} = require('../../constants');
/**
 * @api {amqp} <prefix>.list Retrieve Organizations list
 * @apiVersion 1.0.0
 * @apiName ListOrganizations
 * @apiGroup Organizations
 *
 * @apiDescription This method allows to list organizations. They can be sorted & filtered by
 * any metadata field.
 *
 * @apiParam (Payload) {Number} [offset=0] - cursor for pagination
 * @apiParam (Payload) {Number} [limit=10] - profiles per page
 * @apiParam (Payload) {String="ASC","DESC"} [order=ASC] - sort order
 * @apiParam (Payload) {String} [criteria] - if supplied, sort will be performed based on this field
 * @apiParam (Payload) {Object} [filter] to use, consult https://github.com/makeomatic/redis-filtered-sort, can already be stringified

 * @apiSuccess (Response) {Object[]} data - response data.
 * @apiSuccess (Response) {String} data.id - organization id.
 * @apiSuccess (Response) {String} data.type - response type.
 * @apiSuccess (Response) {String} data.attributes.id - organization id.
 * @apiSuccess (Response) {String} data.attributes.name - organization name.
 * @apiSuccess (Response) {Boolean} data.attributes.active - organization state.
 * @apiSuccess (Response) {Object} data.attributes.metadata - organization metadata
 * @apiSuccess (Response) {Object} meta - response meta.
 * @apiSuccess (Response) {Number} meta.cursor - cursor.
 * @apiSuccess (Response) {Number} meta.page - page.
 * @apiSuccess (Response) {Number} meta.pages - pages.
 * @apiSuccess (Response) {Number} meta.total - total.
 */


async function getOrganizationsList({
  params
}) {
  const {
    redis
  } = this;
  const {
    criteria,
    audience,
    limit = 10,
    offset = 0,
    order = 'ASC',
    expiration = 30000,
    filter
  } = params;
  const strFilter = typeof filter === 'string' ? filter : fsort.filter(filter || {});
  const currentTime = Date.now();
  const organizationsIds = await redis.fsort(ORGANIZATIONS_INDEX, redisKey('*', ORGANIZATIONS_DATA), criteria, order, strFilter, currentTime, offset, limit, expiration);
  const length = +organizationsIds.pop();
  const organizations = await Promise.map(organizationsIds, async organizationId => {
    const [organization, metadata] = await Promise.all([getInternalData.call(this, organizationId, true), getOrganizationMetadata.call(this, organizationId, audience)]);
    return _objectSpread({}, organization, {
      metadata
    });
  });
  return {
    data: organizations.map(organization => ({
      id: organization.id,
      type: 'organization',
      attributes: organization
    })),
    meta: {
      cursor: offset + limit,
      page: Math.floor(offset / limit) + 1,
      pages: Math.ceil(length / limit),
      total: length
    }
  };
}

getOrganizationsList.transports = [ActionTransport.amqp, ActionTransport.internal];
module.exports = getOrganizationsList;
